package com.dcsoft.system.ladder.mapper;

import com.dcsoft.system.domain.SysEquipment;
import com.dcsoft.system.ladder.domain.DeviceTreeVo;
import com.dcsoft.system.ladder.domain.StoreyInfoVo;
import com.dcsoft.system.ladder.domain.TLadderConfig;
import com.dcsoft.system.ladder.domain.TLadderRule;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 梯控基础配置Mapper接口
 *
 * @author dcsoft
 * @date 2023-12-26
 */
public interface TLadderConfigMapper {
    /**
     * 查询梯控基础配置
     *
     * @param id 梯控基础配置主键
     * @return 梯控基础配置
     */
    public TLadderConfig selectTLadderConfigById(String id);

    /**
     * 查询梯控基础配置列表
     *
     * @param tLadderConfig 梯控基础配置
     * @return 梯控基础配置集合
     */
    public List<TLadderConfig> selectTLadderConfigList(@Param("param") TLadderConfig tLadderConfig, @Param("list") List<String> list);

    /**
     * 新增梯控基础配置
     *
     * @param tLadderConfig 梯控基础配置
     * @return 结果
     */
    public int insertTLadderConfig(TLadderConfig tLadderConfig);

    /**
     * 修改梯控基础配置
     *
     * @param tLadderConfig 梯控基础配置
     * @return 结果
     */
    public int updateTLadderConfig(TLadderConfig tLadderConfig);

    /**
     * 删除梯控基础配置
     *
     * @param id 梯控基础配置主键
     * @return 结果
     */
    public int deleteTLadderConfigById(String id);

    /**
     * 批量删除梯控基础配置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTLadderConfigByIds(String[] ids);

    /**
     * 查询设备树
     */
    List<DeviceTreeVo> queryDeviceTree();

    /**
     * 查询设备信息
     */
    SysEquipment queryEquipment(TLadderConfig ladderConfig);

    /**
     * 保存楼层数据
     */
    void saveStoreyInfo(List<TLadderConfig> list);

    /**
     * 刪除楼层信息
     */
    void deleteStoreyInfo(TLadderConfig tLadderConfig);

    int queryStoreyInfoCount(@Param("list") List<String> list, @Param("ladderId") String ladderId);

    /**
     * 查询楼层数据
     */
    List<StoreyInfoVo> queryStoreyInfo(TLadderConfig ladderConfig);

    /**
     * 查询梯口配置是否配置规则
     */
    List<TLadderRule> queryRuleCount(String id);

    /**
     * 查询楼层信息
     * @param list
     * @return
     */
    List<StoreyInfoVo> queryFloorInfo(List<String> list);
}
